==> vmaid-2.1.7.tar.gz: vmaid-2.1.7/src/jump.h <==
/*
    Video maid
    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __JUMP_H__
#define __JUMP_H__


#include "vmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


typedef struct _JumpConfig
{
  gboolean video, audio;
  gint max;
  guint32 rate, scale;
  VmaidCursor cursor, select;
} JumpConfig;


/******************************************************************************
*                                                                             *
* ja:ジャンプダイアログ関数群                                                 *
*                                                                             *
******************************************************************************/
/*  ja:ジャンプダイアログ表示
    jmpcfg,ジャンプ構造体
       RET.TRUE:OK,FALSE:Cancel                                             */
gboolean
jump_dialog (JumpConfig *jmpcfg);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __JUMP_H__ */

==> vmaid-2.2.3.tar.gz: vmaid-2.2.3/src/jump.h <==
/*
    Video maid
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __JUMP_H__
#define __JUMP_H__


#include "vmaid.h"


G_BEGIN_DECLS


typedef struct _JumpConfig
{
  gboolean video, audio;
  gint max;
  guint32 rate, scale;
  VmaidCursor cursor, select;
} JumpConfig;


/******************************************************************************
*                                                                             *
* ja:ジャンプダイアログ関数群                                                 *
*                                                                             *
******************************************************************************/
/*  ja:ジャンプダイアログ表示
    jmpcfg,ジャンプ構造体
       RET.TRUE:OK,FALSE:Cancel                                             */
gboolean
jump_dialog (JumpConfig *jmpcfg);


G_END_DECLS


#endif /* __JUMP_H__ */
